@@ -74,6 +74,10 @@ def whoami(user):
         json.dumps(user, indent=1, sort_keys=True), mimetype='application/json'
     )
 
+@authenticated
+def get_instance(*args, **kwargs):
+    return _PROFILES.get_instance()
+
 @authenticated
 def get_user_cm(user):
     cm = _PROFILES.user.get(user['name'])
