@@ -126,10 +126,28 @@ class OpenShift(object):
       else:
         raise
 
+  def get_gpu_number(self):
+    result = 0
+    nodes = self.oapi_client.resources.get(kind='Node', api_version='v1')
+    node_list = nodes.get()
+    for node in node_list.items:
+      result += int(node.metadata.labels.get('nvidia.com/gpu.count', 0))
+    return result      
+    
   def get_imagestreams(self, label=None):
     imagestreams = self.oapi_client.resources.get(kind='ImageStream', api_version='image.openshift.io/v1')
     imagestream_list = imagestreams.get(namespace=self.namespace, label_selector=label)
     return imagestream_list
+  
+  def get_cluster_version(self, name):
+    cluster_versions = self.oapi_client.resources.get(kind='ClusterVersion', api_version='config.openshift.io/v1')
+    cluster_version =  cluster_versions.get(name=name, namespace=self.namespace)
+    return cluster_version
+
+  def get_builds(self):
+    builds = self.oapi_client.resources.get(kind='Build', api_version='build.openshift.io/v1')
+    build_list = builds.get(namespace=self.namespace)
+    return build_list
 
   def create_pod_mapping(self, name, data, secret=False):
     result = []
