@@ -1,4 +1,10 @@
-import { CM_PATH, SIZES_PATH, IMAGE_PATH, UI_CONFIG_PATH } from '../utils/const';
+import {
+  CM_PATH,
+  SIZES_PATH,
+  IMAGE_PATH,
+  UI_CONFIG_PATH,
+  DEFAULT_IMAGE_PATH,
+} from '../utils/const';
 import { ImageType, SizeDescription, UiConfigType, UserConfigMapType } from '../utils/types';
 
 type MockDataType = {
@@ -9,19 +15,20 @@ type MockDataType = {
   ['size/Medium']: SizeDescription;
   ['size/Large']: SizeDescription;
   [UI_CONFIG_PATH]: UiConfigType;
+  [DEFAULT_IMAGE_PATH]: string;
 };
 
 export const mockData: MockDataType = {
   [CM_PATH]: {
     env: [],
     gpu: 0,
-    last_selected_image: 's2i-generic-data-science-notebook:v0.0:4',
+    last_selected_image: 's2i-generic-data-science-notebook:v0.0.24',
     last_selected_size: 'Default',
   },
+  [DEFAULT_IMAGE_PATH]: 's2i-generic-data-science-notebook:v0.0.4',
   [SIZES_PATH]: ['Small', 'Medium', 'Large'],
   [IMAGE_PATH]: [
     {
-      default: false,
       description:
         'Jupyter notebook image with a set of data science libraries that advanced AI/ML notebooks will use as a base image to provide a standard for libraries available in all notebooks',
       display_name: 'Standard Data Science',
@@ -66,6 +73,7 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.4',
           recommended: false,
+          default: true,
         },
         {
           build_status: 'Unknown',
@@ -105,12 +113,12 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.24',
           recommended: true,
+          default: false,
         },
       ],
       url: 'https://github.com/thoth-station/s2i-generic-data-science-notebook',
     },
     {
-      default: false,
       description: 'Jupyter notebook image with Elyra-AI installed',
       display_name: 'Elyra Notebook Image',
       name: 's2i-lab-elyra',
@@ -129,12 +137,12 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.8',
           recommended: false,
+          default: false,
         },
       ],
       url: 'https://github.com/thoth-station/s2i-lab-elyra',
     },
     {
-      default: false,
       description:
         'Jupyter notebook image with minimal dependency set to start experimenting with Jupyter environment.',
       display_name: 'Minimal Python',
@@ -163,6 +171,7 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.14',
           recommended: true,
+          default: false,
         },
         {
           build_status: 'Unknown',
@@ -186,12 +195,12 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.7',
           recommended: false,
+          default: false,
         },
       ],
       url: 'https://github.com/thoth-station/s2i-minimal-notebook',
     },
     {
-      default: false,
       description:
         'Jupyter notebook image containing basic dependencies for data science and machine learning work.',
       display_name: 'SciPy Notebook Image',
@@ -211,12 +220,12 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.2',
           recommended: false,
+          default: false,
         },
       ],
       url: 'https://github.com/thoth-station/s2i-minimal-notebook',
     },
     {
-      default: false,
       description: null,
       display_name: 'Minimal Python with Apache Spark',
       name: 's2i-spark-minimal-notebook',
@@ -230,19 +239,19 @@ export const mockData: MockDataType = {
           },
           name: 'py36-spark2.4.5-hadoop2.7.3',
           recommended: false,
+          default: false,
         },
       ],
       url: null,
     },
     {
-      default: false,
       description: null,
       display_name: 'Minimal Python with Apache Spark and SciPy',
       name: 's2i-spark-scipy-notebook',
       order: 100,
       tags: [
         {
-          build_status: 'Unknown',
+          build_status: 'failed',
           content: {
             dependencies: [],
             software: [
@@ -254,21 +263,22 @@ export const mockData: MockDataType = {
           },
           name: '3.6',
           recommended: false,
+          default: false,
         },
         {
-          build_status: 'Unknown',
+          build_status: 'pending',
           content: {
             dependencies: [],
             software: [],
           },
           name: '3.5.2',
           recommended: true,
+          default: false,
         },
       ],
       url: null,
     },
     {
-      default: false,
       description: 'Jupyter notebook image containing dependencies for training Tensorflow models.',
       display_name: 'Tensorflow Notebook Image',
       name: 's2i-tensorflow-notebook',
@@ -291,10 +301,58 @@ export const mockData: MockDataType = {
           },
           name: 'v0.0.2',
           recommended: false,
+          default: false,
         },
       ],
       url: 'https://github.com/thoth-station/s2i-tensorflow-notebook',
     },
+    {
+      description: 'Jupyter notebook image containing dependencies for training Tensorflow models.',
+      display_name: 'No Tag Content Notebook Image',
+      name: 'no-tag-content-notebook',
+      order: 100,
+      tags: [
+        {
+          build_status: 'Unknown',
+          name: 'v0.0.2',
+          recommended: false,
+          default: false,
+        },
+        {
+          build_status: 'Unknown',
+          content: {
+            dependencies: [],
+            software: [
+              {
+                name: 'Python',
+                version: 'v3.8.7',
+              },
+              {
+                name: 'Tensorflow CPU',
+                version: 'v2.4.0',
+              },
+            ],
+          },
+          name: 'v0.0.3',
+          recommended: false,
+          default: false,
+        },
+        {
+          build_status: 'Unknown',
+          name: 'v0.0.4',
+          recommended: false,
+          default: false,
+        },
+      ],
+      url: 'https://github.com/thoth-station/s2i-tensorflow-notebook',
+    },
+    {
+      description: 'Jupyter notebook image containing dependencies for training Tensorflow models.',
+      display_name: 'No Tags Notebook Image',
+      name: 'no-tags-notebook',
+      order: 100,
+      url: 'https://github.com/thoth-station/s2i-tensorflow-notebook',
+    },
   ],
   ['size/Small']: {
     name: 'Small',
